"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia status definitions for gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.licensing_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___GetStatusRequest: typing_extensions.TypeAlias = GetStatusRequest

@typing.final
class GetStatusResponse(google.protobuf.message.Message):
    """Status response containing information about the micro-service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ConfigurationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.any_pb2.Any: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.any_pb2.Any | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    MODEL_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the service."""
    version: builtins.str
    """The version of the service."""
    @property
    def configuration(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.any_pb2.Any]:
        """The configuration of the service."""

    @property
    def model_info(self) -> phonexia.grpc.common.licensing_pb2.ModelInfo:
        """The model information."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
        configuration: collections.abc.Mapping[builtins.str, google.protobuf.any_pb2.Any] | None = ...,
        model_info: phonexia.grpc.common.licensing_pb2.ModelInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_model_info", b"_model_info", "model_info", b"model_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_model_info", b"_model_info", "configuration", b"configuration", "model_info", b"model_info", "name", b"name", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_model_info", b"_model_info"]) -> typing.Literal["model_info"] | None: ...

Global___GetStatusResponse: typing_extensions.TypeAlias = GetStatusResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Enhanced Speech To Text Built On Whisper gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TranscribeRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Transcribe</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data from which a transcription should be extracted.
        A variety of common audio formats are supported, including WAV, FLAC,
        and others. There is no minimum audio length limit.
        """

    @property
    def config(self) -> Global___TranscribeConfig:
        """Speech to text transcription configuration."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___TranscribeConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

Global___TranscribeRequest: typing_extensions.TypeAlias = TranscribeRequest

@typing.final
class TranscribeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    ENABLE_LANGUAGE_SWITCHING_FIELD_NUMBER: builtins.int
    ENABLE_WORD_SEGMENTATION_FIELD_NUMBER: builtins.int
    language: builtins.str
    """The language of the audio data specified as an RFC 5646 language tag.
    If not set, the language will be detected automatically.
    """
    enable_language_switching: builtins.bool
    """By default, the language of the speech is detected once at the beginning of
    the audio. Setting `enable_language_switching` to `true` allows for dynamic
    language switching in the audio, with the language being detected
    approximately every 30 seconds.

    Note: This option is ignored if the language is enforced by setting the
    <code>language</code> option.
    """
    enable_word_segmentation: builtins.bool
    """If set to `true`, the result will contain word-level segmentation.

    Note: Enabling this option may incrase processing time.
    """
    def __init__(
        self,
        *,
        language: builtins.str = ...,
        enable_language_switching: builtins.bool = ...,
        enable_word_segmentation: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enable_language_switching", b"enable_language_switching", "enable_word_segmentation", b"enable_word_segmentation", "language", b"language"]) -> None: ...

Global___TranscribeConfig: typing_extensions.TypeAlias = TranscribeConfig

@typing.final
class TranslateRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Translate</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data on which the translation should be performed.
        A variety of common audio formats are supported, including WAV, FLAC,
        and others. There is no minimum audio length limit.
        """

    @property
    def config(self) -> Global___TranslateConfig:
        """Speech to text translation configuration."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___TranslateConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

Global___TranslateRequest: typing_extensions.TypeAlias = TranslateRequest

@typing.final
class TranslateConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_LANGUAGE_FIELD_NUMBER: builtins.int
    ENABLE_LANGUAGE_SWITCHING_FIELD_NUMBER: builtins.int
    ENABLE_WORD_SEGMENTATION_FIELD_NUMBER: builtins.int
    source_language: builtins.str
    """The language of the audio data specified as an RFC 5646 language tag.
    If not set, the language will be detected automatically.
    """
    enable_language_switching: builtins.bool
    """By default, the language of the speech is detected once at the beginning of
    the audio. Setting `enable_language_switching` to `true` allows for dynamic
    language switching in the audio, with the language being detected
    approximately every 30 seconds.

    Note: This option is ignored if the language is enforced by setting the
    <code>source_language</code> option.
    """
    enable_word_segmentation: builtins.bool
    """If set to `true`, the result will contain word-level segmentation.

    Note: Enabling this option may increase processing time.
    """
    def __init__(
        self,
        *,
        source_language: builtins.str = ...,
        enable_language_switching: builtins.bool = ...,
        enable_word_segmentation: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enable_language_switching", b"enable_language_switching", "enable_word_segmentation", b"enable_word_segmentation", "source_language", b"source_language"]) -> None: ...

Global___TranslateConfig: typing_extensions.TypeAlias = TranslateConfig

@typing.final
class TranscribeResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Transcribe</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___TranscribeResult:
        """The Speech to Text transcription result."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: Global___TranscribeResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___TranscribeResponse: typing_extensions.TypeAlias = TranscribeResponse

@typing.final
class TranslateResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Translate</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___TranslateResult:
        """The Speech to Text translation result."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: Global___TranslateResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___TranslateResponse: typing_extensions.TypeAlias = TranslateResponse

@typing.final
class ListSupportedLanguagesRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>ListSupportedLanguages</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ListSupportedLanguagesRequest: typing_extensions.TypeAlias = ListSupportedLanguagesRequest

@typing.final
class ListSupportedLanguagesResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>ListSupportedLanguages</code>"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGES_FIELD_NUMBER: builtins.int
    TRANSLATION_LANGUAGES_FIELD_NUMBER: builtins.int
    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of available languages for transcription.
        The language is specified as an RFC 5646 language tag.
        """

    @property
    def translation_languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of available source languages for translation.
        The language is specified as an RFC 5646 language tag.
        """

    def __init__(
        self,
        *,
        languages: collections.abc.Iterable[builtins.str] | None = ...,
        translation_languages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["languages", b"languages", "translation_languages", b"translation_languages"]) -> None: ...

Global___ListSupportedLanguagesResponse: typing_extensions.TypeAlias = ListSupportedLanguagesResponse

@typing.final
class TranscribeResult(google.protobuf.message.Message):
    """The collection of all transcription result formats."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONE_BEST_FIELD_NUMBER: builtins.int
    @property
    def one_best(self) -> Global___OneBest:
        """Result in one-best format."""

    def __init__(
        self,
        *,
        one_best: Global___OneBest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["one_best", b"one_best"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["one_best", b"one_best"]) -> None: ...

Global___TranscribeResult: typing_extensions.TypeAlias = TranscribeResult

@typing.final
class TranslateResult(google.protobuf.message.Message):
    """The collection of all translation result formats."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONE_BEST_FIELD_NUMBER: builtins.int
    @property
    def one_best(self) -> Global___OneBest:
        """Result in one-best format."""

    def __init__(
        self,
        *,
        one_best: Global___OneBest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["one_best", b"one_best"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["one_best", b"one_best"]) -> None: ...

Global___TranslateResult: typing_extensions.TypeAlias = TranslateResult

@typing.final
class OneBest(google.protobuf.message.Message):
    """The one-best output from Speech To Text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___OneBestSegment]:
        """Sequential list of transcription segments corresponding to sequential
        portions of audio.
        """

    def __init__(
        self,
        *,
        segments: collections.abc.Iterable[Global___OneBestSegment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["segments", b"segments"]) -> None: ...

Global___OneBest: typing_extensions.TypeAlias = OneBest

@typing.final
class Word(google.protobuf.message.Message):
    """Individual word with timestamps."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    PUNCTUATED_TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text of the word."""
    punctuated_text: builtins.str
    """Text of the word with punctuation and capitalization."""
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the word."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the word."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        punctuated_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "punctuated_text", b"punctuated_text", "start_time", b"start_time", "text", b"text"]) -> None: ...

Global___Word: typing_extensions.TypeAlias = Word

@typing.final
class OneBestSegment(google.protobuf.message.Message):
    """Segment of the one-best output."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    SOURCE_LANGUAGE_FIELD_NUMBER: builtins.int
    DETECTED_SOURCE_LANGUAGE_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text content of the segment."""
    language: builtins.str
    """Target language, that the <code>text</code> field of this message is transcribed in.
    The language is specified as an RFC 5646 language tag.

    Note: If a specific language was enforced in the <code>Transcribe</code> method,
    the target language is the same as this specified language.
    """
    source_language: builtins.str
    """The selected language of the audio data as an RFC 5646 language tag.
    This field contains the language that whisper used for transcription/translation.
    In case that the user does not have a license for the language identified in the
    audio data, this field may not contain this language. Rather it will contain the most probable
    of the licensed languages.
    Note that this will have radical influence on the output, so always compare this field
    against <code>detected_source_language</code> to know if the text is transcribed/translated
    to/from the correct language.

    Note: If a specific <code>source_language</code> was enforced in the config,
    this field is the same as that specified language.
    """
    detected_source_language: builtins.str
    """The detected language of the audio data as an RFC 5646 language tag.
    This field contains the language that whisper detected as the source language of the audio data.
    This field may not equal to <code>source_language</code> in case the audio data is in different
    language than from the set of licensed languages.
    Always check if this field is equal to <code>source_language</code>.
    """
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the segment."""

    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Word]:
        """Detailed word-level segmentation of the segment."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        language: builtins.str = ...,
        source_language: builtins.str = ...,
        detected_source_language: builtins.str = ...,
        words: collections.abc.Iterable[Global___Word] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["detected_source_language", b"detected_source_language", "end_time", b"end_time", "language", b"language", "source_language", b"source_language", "start_time", b"start_time", "text", b"text", "words", b"words"]) -> None: ...

Global___OneBestSegment: typing_extensions.TypeAlias = OneBestSegment



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Speaker Identification gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompareRequest(google.protobuf.message.Message):
    """The message sent by the client for the <code>Compare</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICEPRINTS_A_FIELD_NUMBER: builtins.int
    VOICEPRINTS_B_FIELD_NUMBER: builtins.int
    @property
    def voiceprints_a(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """First list of voiceprints to be compared."""

    @property
    def voiceprints_b(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """Second list of voiceprints to be compared."""

    def __init__(
        self,
        *,
        voiceprints_a: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
        voiceprints_b: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["voiceprints_a", b"voiceprints_a", "voiceprints_b", b"voiceprints_b"]) -> None: ...

Global___CompareRequest: typing_extensions.TypeAlias = CompareRequest

@typing.final
class CompareResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Compare</code>
    method. It contains comparison matrix of log-likelihood ratio (LLR) scores.
    Comparison matrix containing similarity scores between
    <code>voiceprints_a</code> and <code>voiceprints_b</code>. The element at
    row <code>i</code> and column <code>j</code> corresponds to the comparison
    result between <code>voiceprints_a[i]</code> and
    <code>voiceprints_b[j]</code>.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORES_FIELD_NUMBER: builtins.int
    @property
    def scores(self) -> phonexia.grpc.common.core_pb2.Matrix:
        """The similarity scores are expressed as log-likelihood ratio (LLR) values,
        which fall within the interval of <code>(-inf;+inf)</code>, with higher
        values indicating higher similarity.
        """

    def __init__(
        self,
        *,
        scores: phonexia.grpc.common.core_pb2.Matrix | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scores", b"scores"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["scores", b"scores"]) -> None: ...

Global___CompareResponse: typing_extensions.TypeAlias = CompareResponse

@typing.final
class ExtractRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Extract</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio to extract the voiceprints from.
        If the audio is in a raw format and the <code>config.speech_length</code> is
        set, the result can be returned before the whole audio was transferred if the
        requirement for speech length were met.
        There is no minimum audio length limit.
        """

    @property
    def config(self) -> Global___ExtractConfig:
        """Voiceprint extraction configuration."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___ExtractConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

Global___ExtractRequest: typing_extensions.TypeAlias = ExtractRequest

@typing.final
class ExtractConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    ENABLE_VECTOR_VOICEPRINT_FIELD_NUMBER: builtins.int
    enable_vector_voiceprint: builtins.bool
    """If set to true, the extraction result will contain both voiceprint
    and vector_voiceprint fields. If false (default), only voiceprint is returned.
    """
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the voiceprint will be
        extracted. If there is less speech in the audio than the specified
        duration, the voiceprint will be extracted from the entire audio.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        enable_vector_voiceprint: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enable_vector_voiceprint", b"enable_vector_voiceprint", "speech_length", b"speech_length"]) -> None: ...

Global___ExtractConfig: typing_extensions.TypeAlias = ExtractConfig

@typing.final
class ExtractResult(google.protobuf.message.Message):
    """A voiceprint extraction result."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    VOICEPRINT_FIELD_NUMBER: builtins.int
    VECTOR_VOICEPRINT_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Speech length from which the voiceprint was extracted."""

    @property
    def voiceprint(self) -> phonexia.grpc.common.core_pb2.Voiceprint:
        """Extracted voiceprint is always included in the result."""

    @property
    def vector_voiceprint(self) -> phonexia.grpc.common.core_pb2.Vector:
        """Vector voiceprint optimized for vector databases.
        Included only if enable_vector_voiceprint is set to true in ExtractConfig.
        Use cosine distance to compare vector voiceprints in vector databases.
        Note: Will be empty if the input audio contains no speech.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        voiceprint: phonexia.grpc.common.core_pb2.Voiceprint | None = ...,
        vector_voiceprint: phonexia.grpc.common.core_pb2.Vector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length", "vector_voiceprint", b"vector_voiceprint", "voiceprint", b"voiceprint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length", "vector_voiceprint", b"vector_voiceprint", "voiceprint", b"voiceprint"]) -> None: ...

Global___ExtractResult: typing_extensions.TypeAlias = ExtractResult

@typing.final
class ExtractResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Extract</code>
    method. It contains the result as zero or more <code>ExtractResult</code>
    messages.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___ExtractResult:
        """Result containing the extracted voiceprint."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """When available, total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: Global___ExtractResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___ExtractResponse: typing_extensions.TypeAlias = ExtractResponse

@typing.final
class MergeRequest(google.protobuf.message.Message):
    """The message sent by the client for the <code>Merge</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICEPRINTS_FIELD_NUMBER: builtins.int
    @property
    def voiceprints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """List of voiceprints to be merged."""

    def __init__(
        self,
        *,
        voiceprints: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["voiceprints", b"voiceprints"]) -> None: ...

Global___MergeRequest: typing_extensions.TypeAlias = MergeRequest

@typing.final
class MergeResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Merge</code>
    method. It contains the merged voiceprint.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    VOICEPRINT_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Speech length of merged voiceprint. It's a sum of all input voiceprints' lengths."""

    @property
    def voiceprint(self) -> phonexia.grpc.common.core_pb2.Voiceprint:
        """Merged voiceprint."""

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        voiceprint: phonexia.grpc.common.core_pb2.Voiceprint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length", "voiceprint", b"voiceprint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length", "voiceprint", b"voiceprint"]) -> None: ...

Global___MergeResponse: typing_extensions.TypeAlias = MergeResponse

@typing.final
class ConvertRequest(google.protobuf.message.Message):
    """The message sent by the client for the <code>Convert</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICEPRINTS_FIELD_NUMBER: builtins.int
    @property
    def voiceprints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """Voiceprints to be converted to vector database format."""

    def __init__(
        self,
        *,
        voiceprints: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["voiceprints", b"voiceprints"]) -> None: ...

Global___ConvertRequest: typing_extensions.TypeAlias = ConvertRequest

@typing.final
class ConvertResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Convert</code>
    method. It contains the converted vectors.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VECTOR_VOICEPRINTS_FIELD_NUMBER: builtins.int
    @property
    def vector_voiceprints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Vector]:
        """Voiceprints converted to vector format for vector databases.
        Use cosine distance to compare vector voiceprints in vector databases.
        Note: Individual vectors will be empty for input voiceprints that contain no speech.
        """

    def __init__(
        self,
        *,
        vector_voiceprints: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Vector] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vector_voiceprints", b"vector_voiceprints"]) -> None: ...

Global___ConvertResponse: typing_extensions.TypeAlias = ConvertResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/gender_identification/v1/gender_identification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/gender_identification/v1/gender_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOphonexia/grpc/technologies/gender_identification/v1/gender_identification.proto\x12\x33phonexia.grpc.technologies.gender_identification.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xc9\x01\n\x0fIdentifyRequest\x12\x35\n\x0bvoiceprints\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12*\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12S\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x43.phonexia.grpc.technologies.gender_identification.v1.IdentifyConfig\"B\n\x0eIdentifyConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"/\n\x05Score\x12\x11\n\tscore_llr\x18\x01 \x01(\x02\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\"\x8e\x02\n\x0eIdentifyResult\x12S\n\nscore_male\x18\x01 \x01(\x0b\x32:.phonexia.grpc.technologies.gender_identification.v1.ScoreH\x00\x88\x01\x01\x12U\n\x0cscore_female\x18\x02 \x01(\x0b\x32:.phonexia.grpc.technologies.gender_identification.v1.ScoreH\x01\x88\x01\x01\x12\x30\n\rspeech_length\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\n\x0b_score_maleB\x0f\n\r_score_female\"\xa3\x01\n\x10IdentifyResponse\x12T\n\x07results\x18\x01 \x03(\x0b\x32\x43.phonexia.grpc.technologies.gender_identification.v1.IdentifyResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb4\x01\n\x14GenderIdentification\x12\x9b\x01\n\x08Identify\x12\x44.phonexia.grpc.technologies.gender_identification.v1.IdentifyRequest\x1a\x45.phonexia.grpc.technologies.gender_identification.v1.IdentifyResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.gender_identification.v1.gender_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IDENTIFYREQUEST']._serialized_start=202
  _globals['_IDENTIFYREQUEST']._serialized_end=403
  _globals['_IDENTIFYCONFIG']._serialized_start=405
  _globals['_IDENTIFYCONFIG']._serialized_end=471
  _globals['_SCORE']._serialized_start=473
  _globals['_SCORE']._serialized_end=520
  _globals['_IDENTIFYRESULT']._serialized_start=523
  _globals['_IDENTIFYRESULT']._serialized_end=793
  _globals['_IDENTIFYRESPONSE']._serialized_start=796
  _globals['_IDENTIFYRESPONSE']._serialized_end=959
  _globals['_GENDERIDENTIFICATION']._serialized_start=962
  _globals['_GENDERIDENTIFICATION']._serialized_end=1142
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/common/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/common/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from phonexia.grpc.common import licensing_pb2 as phonexia_dot_grpc_dot_common_dot_licensing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!phonexia/grpc/common/status.proto\x12\x14phonexia.grpc.common\x1a\x19google/protobuf/any.proto\x1a$phonexia/grpc/common/licensing.proto\"\x12\n\x10GetStatusRequest\"\x9a\x02\n\x11GetStatusResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12Q\n\rconfiguration\x18\x03 \x03(\x0b\x32:.phonexia.grpc.common.GetStatusResponse.ConfigurationEntry\x12\x38\n\nmodel_info\x18\x04 \x01(\x0b\x32\x1f.phonexia.grpc.common.ModelInfoH\x00\x88\x01\x01\x1aJ\n\x12\x43onfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\x42\r\n\x0b_model_info2f\n\x06Status\x12\\\n\tGetStatus\x12&.phonexia.grpc.common.GetStatusRequest\x1a\'.phonexia.grpc.common.GetStatusResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.common.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._loaded_options = None
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATUSREQUEST']._serialized_start=124
  _globals['_GETSTATUSREQUEST']._serialized_end=142
  _globals['_GETSTATUSRESPONSE']._serialized_start=145
  _globals['_GETSTATUSRESPONSE']._serialized_end=427
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._serialized_start=338
  _globals['_GETSTATUSRESPONSE_CONFIGURATIONENTRY']._serialized_end=412
  _globals['_STATUS']._serialized_start=429
  _globals['_STATUS']._serialized_end=531
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/enhanced_speech_to_text_built_on_whisper/v1/enhanced_speech_to_text_built_on_whisper.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/enhanced_speech_to_text_built_on_whisper/v1/enhanced_speech_to_text_built_on_whisper.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nuphonexia/grpc/technologies/enhanced_speech_to_text_built_on_whisper/v1/enhanced_speech_to_text_built_on_whisper.proto\x12\x46phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\xa9\x01\n\x11TranscribeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12h\n\x06\x63onfig\x18\x02 \x01(\x0b\x32X.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeConfig\"i\n\x10TranscribeConfig\x12\x10\n\x08language\x18\x01 \x01(\t\x12!\n\x19\x65nable_language_switching\x18\x02 \x01(\x08\x12 \n\x18\x65nable_word_segmentation\x18\x03 \x01(\x08\"\xa7\x01\n\x10TranslateRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12g\n\x06\x63onfig\x18\x02 \x01(\x0b\x32W.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateConfig\"o\n\x0fTranslateConfig\x12\x17\n\x0fsource_language\x18\x01 \x01(\t\x12!\n\x19\x65nable_language_switching\x18\x02 \x01(\x08\x12 \n\x18\x65nable_word_segmentation\x18\x03 \x01(\x08\"\xb9\x01\n\x12TranscribeResponse\x12h\n\x06result\x18\x01 \x01(\x0b\x32X.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xb7\x01\n\x11TranslateResponse\x12g\n\x06result\x18\x01 \x01(\x0b\x32W.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1f\n\x1dListSupportedLanguagesRequest\"R\n\x1eListSupportedLanguagesResponse\x12\x11\n\tlanguages\x18\x01 \x03(\t\x12\x1d\n\x15translation_languages\x18\x02 \x03(\t\"u\n\x10TranscribeResult\x12\x61\n\x08one_best\x18\x01 \x01(\x0b\x32O.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.OneBest\"t\n\x0fTranslateResult\x12\x61\n\x08one_best\x18\x01 \x01(\x0b\x32O.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.OneBest\"s\n\x07OneBest\x12h\n\x08segments\x18\x01 \x03(\x0b\x32V.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.OneBestSegment\"\x89\x01\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x17\n\x0fpunctuated_text\x18\x04 \x01(\t\"\xa4\x02\n\x0eOneBestSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x17\n\x0fsource_language\x18\x05 \x01(\t\x12 \n\x18\x64\x65tected_source_language\x18\x06 \x01(\t\x12[\n\x05words\x18\x07 \x03(\x0b\x32L.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.Word2\x89\x05\n\x0cSpeechToText\x12\xc7\x01\n\nTranscribe\x12Y.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeRequest\x1aZ.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranscribeResponse(\x01\x30\x01\x12\xc4\x01\n\tTranslate\x12X.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateRequest\x1aY.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.TranslateResponse(\x01\x30\x01\x12\xe7\x01\n\x16ListSupportedLanguages\x12\x65.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.ListSupportedLanguagesRequest\x1a\x66.phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.ListSupportedLanguagesResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.enhanced_speech_to_text_built_on_whisper_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRANSCRIBEREQUEST']._serialized_start=259
  _globals['_TRANSCRIBEREQUEST']._serialized_end=428
  _globals['_TRANSCRIBECONFIG']._serialized_start=430
  _globals['_TRANSCRIBECONFIG']._serialized_end=535
  _globals['_TRANSLATEREQUEST']._serialized_start=538
  _globals['_TRANSLATEREQUEST']._serialized_end=705
  _globals['_TRANSLATECONFIG']._serialized_start=707
  _globals['_TRANSLATECONFIG']._serialized_end=818
  _globals['_TRANSCRIBERESPONSE']._serialized_start=821
  _globals['_TRANSCRIBERESPONSE']._serialized_end=1006
  _globals['_TRANSLATERESPONSE']._serialized_start=1009
  _globals['_TRANSLATERESPONSE']._serialized_end=1192
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_start=1194
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_end=1225
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_start=1227
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_end=1309
  _globals['_TRANSCRIBERESULT']._serialized_start=1311
  _globals['_TRANSCRIBERESULT']._serialized_end=1428
  _globals['_TRANSLATERESULT']._serialized_start=1430
  _globals['_TRANSLATERESULT']._serialized_end=1546
  _globals['_ONEBEST']._serialized_start=1548
  _globals['_ONEBEST']._serialized_end=1663
  _globals['_WORD']._serialized_start=1666
  _globals['_WORD']._serialized_end=1803
  _globals['_ONEBESTSEGMENT']._serialized_start=1806
  _globals['_ONEBESTSEGMENT']._serialized_end=2098
  _globals['_SPEECHTOTEXT']._serialized_start=2101
  _globals['_SPEECHTOTEXT']._serialized_end=2750
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.gender_identification.v1 import gender_identification_pb2 as phonexia_dot_grpc_dot_technologies_dot_gender__identification_dot_v1_dot_gender__identification__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in phonexia/grpc/technologies/gender_identification/v1/gender_identification_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class GenderIdentificationStub(object):
    """Service that implements gender identification.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Identify = channel.stream_stream(
                '/phonexia.grpc.technologies.gender_identification.v1.GenderIdentification/Identify',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_gender__identification_dot_v1_dot_gender__identification__pb2.IdentifyRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_gender__identification_dot_v1_dot_gender__identification__pb2.IdentifyResponse.FromString,
                _registered_method=True)


class GenderIdentificationServicer(object):
    """Service that implements gender identification.
    """

    def Identify(self, request_iterator, context):
        """Performs synchronous gender identification from one or more voiceprints or audio.
        Identification is performed on each received chunk, and partial results
        corresponding to each chunk are returned when using voiceprints. Only single
        result is returned when using audio.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GenderIdentificationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Identify': grpc.stream_stream_rpc_method_handler(
                    servicer.Identify,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_gender__identification_dot_v1_dot_gender__identification__pb2.IdentifyRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_gender__identification_dot_v1_dot_gender__identification__pb2.IdentifyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.gender_identification.v1.GenderIdentification', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.gender_identification.v1.GenderIdentification', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GenderIdentification(object):
    """Service that implements gender identification.
    """

    @staticmethod
    def Identify(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.gender_identification.v1.GenderIdentification/Identify',
            phonexia_dot_grpc_dot_technologies_dot_gender__identification_dot_v1_dot_gender__identification__pb2.IdentifyRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_gender__identification_dot_v1_dot_gender__identification__pb2.IdentifyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.speaker_identification.v1 import speaker_identification_pb2 as phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in phonexia/grpc/technologies/speaker_identification/v1/speaker_identification_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class VoiceprintComparisonStub(object):
    """Service that implements voiceprint comparison.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Compare = channel.stream_stream(
                '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison/Compare',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareResponse.FromString,
                _registered_method=True)


class VoiceprintComparisonServicer(object):
    """Service that implements voiceprint comparison.
    """

    def Compare(self, request_iterator, context):
        """Performs synchronous comparison of two voiceprint lists. Each voiceprint
        from one list is compared with each voiceprint from other list. Returns a
        message containing matrix of comparison scores (results of individual
        voiceprint-to-voiceprint comparisons).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VoiceprintComparisonServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Compare': grpc.stream_stream_rpc_method_handler(
                    servicer.Compare,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VoiceprintComparison(object):
    """Service that implements voiceprint comparison.
    """

    @staticmethod
    def Compare(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintComparison/Compare',
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.CompareResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class VoiceprintExtractionStub(object):
    """Service that implements voiceprint extraction.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Extract = channel.stream_unary(
                '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction/Extract',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractResponse.FromString,
                _registered_method=True)


class VoiceprintExtractionServicer(object):
    """Service that implements voiceprint extraction.
    """

    def Extract(self, request_iterator, context):
        """Performs synchronous voiceprint extraction from an audio. Returns the
        result after completely sent and processed audio.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VoiceprintExtractionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Extract': grpc.stream_unary_rpc_method_handler(
                    servicer.Extract,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VoiceprintExtraction(object):
    """Service that implements voiceprint extraction.
    """

    @staticmethod
    def Extract(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintExtraction/Extract',
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ExtractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class VoiceprintMergingStub(object):
    """Service that implements voiceprint merging.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Merge = channel.unary_unary(
                '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintMerging/Merge',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.MergeRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.MergeResponse.FromString,
                _registered_method=True)


class VoiceprintMergingServicer(object):
    """Service that implements voiceprint merging.
    """

    def Merge(self, request, context):
        """Merges a list of voiceprints into a single voiceprint. The new voiceprint
        is a combination of all voiceprints in the list. It uses a weighted arithmetic mean
        by weighting each voiceprint by its speech length.
        This method is intended for merging voiceprints of a single speaker,
        not for merging voiceprints from multiple different speakers.
        Note that the resulting voiceprint is not the same as the voiceprint
        extracted from a file created by concatenating all individual audio files
        into one, but it is very similar.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VoiceprintMergingServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Merge': grpc.unary_unary_rpc_method_handler(
                    servicer.Merge,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.MergeRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.MergeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.speaker_identification.v1.VoiceprintMerging', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.speaker_identification.v1.VoiceprintMerging', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VoiceprintMerging(object):
    """Service that implements voiceprint merging.
    """

    @staticmethod
    def Merge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintMerging/Merge',
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.MergeRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.MergeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class VoiceprintConversionStub(object):
    """Service that implements voiceprint conversion to vector database format.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Convert = channel.stream_stream(
                '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintConversion/Convert',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ConvertRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ConvertResponse.FromString,
                _registered_method=True)


class VoiceprintConversionServicer(object):
    """Service that implements voiceprint conversion to vector database format.
    """

    def Convert(self, request_iterator, context):
        """Converts a voiceprint to a vector optimized for
        vector database usage. This enables efficient similarity search and
        storage in vector database systems.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VoiceprintConversionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Convert': grpc.stream_stream_rpc_method_handler(
                    servicer.Convert,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ConvertRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ConvertResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.speaker_identification.v1.VoiceprintConversion', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.speaker_identification.v1.VoiceprintConversion', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VoiceprintConversion(object):
    """Service that implements voiceprint conversion to vector database format.
    """

    @staticmethod
    def Convert(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.speaker_identification.v1.VoiceprintConversion/Convert',
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ConvertRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speaker__identification_dot_v1_dot_speaker__identification__pb2.ConvertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Transcription Normalization gRPC API
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class NormalizeRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Normalize</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENTS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Segment]:
        """Sequential list of transcription segments corresponding to sequential
        portions of audio.
        """

    @property
    def config(self) -> Global___NormalizeConfig:
        """Configuration of the normalization."""

    def __init__(
        self,
        *,
        segments: collections.abc.Iterable[Global___Segment] | None = ...,
        config: Global___NormalizeConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_config", b"_config", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_config", b"_config", "config", b"config", "segments", b"segments"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_config", b"_config"]) -> typing.Literal["config"] | None: ...

Global___NormalizeRequest: typing_extensions.TypeAlias = NormalizeRequest

@typing.final
class NormalizeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    language: builtins.str
    """The language of the text data specified as an RFC 5646 language tag.
    It is used for converting numbers written out of words to digits. Numbers are not converted if this field is not set.
    """
    def __init__(
        self,
        *,
        language: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_language", b"_language", "language", b"language"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_language", b"_language", "language", b"language"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_language", b"_language"]) -> typing.Literal["language"] | None: ...

Global___NormalizeConfig: typing_extensions.TypeAlias = NormalizeConfig

@typing.final
class NormalizeResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Normalize</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Segment]:
        """Sequential list of transcription segments corresponding to sequential
        portions of audio.
        """

    def __init__(
        self,
        *,
        segments: collections.abc.Iterable[Global___Segment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["segments", b"segments"]) -> None: ...

Global___NormalizeResponse: typing_extensions.TypeAlias = NormalizeResponse

@typing.final
class Word(google.protobuf.message.Message):
    """Individual word with timestamps."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    PUNCTUATED_TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text of the word."""
    punctuated_text: builtins.str
    """Punctuated text of the word."""
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the word."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the word."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        punctuated_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "punctuated_text", b"punctuated_text", "start_time", b"start_time", "text", b"text"]) -> None: ...

Global___Word: typing_extensions.TypeAlias = Word

@typing.final
class Segment(google.protobuf.message.Message):
    """Transcription segment."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text content of the whole segment."""
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the segment."""

    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Word]:
        """Detailed word-level segmentation of the segment."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        words: collections.abc.Iterable[Global___Word] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time", "text", b"text", "words", b"words"]) -> None: ...

Global___Segment: typing_extensions.TypeAlias = Segment



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Audio Quality Estimation gRPC API.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class EstimateRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Estimate</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data for which Audio Quality Estimation should be performed.
        At least 1 millisecond of audio is required, otherwise the result will not contain
        any estimations.
        """

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio"]) -> None: ...

Global___EstimateRequest: typing_extensions.TypeAlias = EstimateRequest

@typing.final
class EstimateResult(google.protobuf.message.Message):
    """The collection of all Audio Quality Estimation result types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PESQ_ESTIMATION_FIELD_NUMBER: builtins.int
    SIGNAL_NOISE_RATIO_FIELD_NUMBER: builtins.int
    AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    MAX_AMPLITUDE_FIELD_NUMBER: builtins.int
    MIN_AMPLITUDE_FIELD_NUMBER: builtins.int
    PEAK_AMPLITUDE_FIELD_NUMBER: builtins.int
    MEAN_AMPLITUDE_FIELD_NUMBER: builtins.int
    SAMPLING_RATE_FIELD_NUMBER: builtins.int
    pesq_estimation: builtins.float
    """Estimation of Perceptual Evaluation of Speech Quality."""
    signal_noise_ratio: builtins.float
    """Signal to Noise Ratio in decibels based on waveform distribution."""
    audio_length: builtins.float
    """Total length of the audio in seconds."""
    max_amplitude: builtins.float
    """Maximum amplitude of the signal, typically a positive number in the interval of
    [-1, 1].
    """
    min_amplitude: builtins.float
    """Minimum amplitude of the signal, typically a negative number in the interval of
    [-1, 1].
    """
    peak_amplitude: builtins.float
    """Maximum absolute value of the signal (i.e., the higher of the absolute values of
    `max_amplitude` and `min_amplitude`).
    """
    mean_amplitude: builtins.float
    """Arithmetic mean of the sample amplitudes."""
    sampling_rate: builtins.int
    """Sampling rate in hertz of the audio."""
    def __init__(
        self,
        *,
        pesq_estimation: builtins.float | None = ...,
        signal_noise_ratio: builtins.float | None = ...,
        audio_length: builtins.float | None = ...,
        max_amplitude: builtins.float | None = ...,
        min_amplitude: builtins.float | None = ...,
        peak_amplitude: builtins.float | None = ...,
        mean_amplitude: builtins.float | None = ...,
        sampling_rate: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_audio_length", b"_audio_length", "_max_amplitude", b"_max_amplitude", "_mean_amplitude", b"_mean_amplitude", "_min_amplitude", b"_min_amplitude", "_peak_amplitude", b"_peak_amplitude", "_pesq_estimation", b"_pesq_estimation", "_sampling_rate", b"_sampling_rate", "_signal_noise_ratio", b"_signal_noise_ratio", "audio_length", b"audio_length", "max_amplitude", b"max_amplitude", "mean_amplitude", b"mean_amplitude", "min_amplitude", b"min_amplitude", "peak_amplitude", b"peak_amplitude", "pesq_estimation", b"pesq_estimation", "sampling_rate", b"sampling_rate", "signal_noise_ratio", b"signal_noise_ratio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_audio_length", b"_audio_length", "_max_amplitude", b"_max_amplitude", "_mean_amplitude", b"_mean_amplitude", "_min_amplitude", b"_min_amplitude", "_peak_amplitude", b"_peak_amplitude", "_pesq_estimation", b"_pesq_estimation", "_sampling_rate", b"_sampling_rate", "_signal_noise_ratio", b"_signal_noise_ratio", "audio_length", b"audio_length", "max_amplitude", b"max_amplitude", "mean_amplitude", b"mean_amplitude", "min_amplitude", b"min_amplitude", "peak_amplitude", b"peak_amplitude", "pesq_estimation", b"pesq_estimation", "sampling_rate", b"sampling_rate", "signal_noise_ratio", b"signal_noise_ratio"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_audio_length", b"_audio_length"]) -> typing.Literal["audio_length"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_max_amplitude", b"_max_amplitude"]) -> typing.Literal["max_amplitude"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_mean_amplitude", b"_mean_amplitude"]) -> typing.Literal["mean_amplitude"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_min_amplitude", b"_min_amplitude"]) -> typing.Literal["min_amplitude"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_peak_amplitude", b"_peak_amplitude"]) -> typing.Literal["peak_amplitude"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_pesq_estimation", b"_pesq_estimation"]) -> typing.Literal["pesq_estimation"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_sampling_rate", b"_sampling_rate"]) -> typing.Literal["sampling_rate"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_signal_noise_ratio", b"_signal_noise_ratio"]) -> typing.Literal["signal_noise_ratio"] | None: ...

Global___EstimateResult: typing_extensions.TypeAlias = EstimateResult

@typing.final
class EstimateResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Estimate</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___EstimateResult:
        """Audio Quality Estimation result."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: Global___EstimateResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___EstimateResponse: typing_extensions.TypeAlias = EstimateResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/age_estimation/v1/age_estimation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/age_estimation/v1/age_estimation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAphonexia/grpc/technologies/age_estimation/v1/age_estimation.proto\x12,phonexia.grpc.technologies.age_estimation.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xc2\x01\n\x0f\x45stimateRequest\x12\x35\n\x0bvoiceprints\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12*\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12L\n\x06\x63onfig\x18\x03 \x01(\x0b\x32<.phonexia.grpc.technologies.age_estimation.v1.EstimateConfig\"B\n\x0e\x45stimateConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\\\n\x0e\x45stimateResult\x12\x10\n\x03\x61ge\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x30\n\rspeech_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x06\n\x04_age\"\x9c\x01\n\x10\x45stimateResponse\x12M\n\x07results\x18\x01 \x03(\x0b\x32<.phonexia.grpc.technologies.age_estimation.v1.EstimateResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\x9f\x01\n\rAgeEstimation\x12\x8d\x01\n\x08\x45stimate\x12=.phonexia.grpc.technologies.age_estimation.v1.EstimateRequest\x1a>.phonexia.grpc.technologies.age_estimation.v1.EstimateResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.age_estimation.v1.age_estimation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ESTIMATEREQUEST']._serialized_start=181
  _globals['_ESTIMATEREQUEST']._serialized_end=375
  _globals['_ESTIMATECONFIG']._serialized_start=377
  _globals['_ESTIMATECONFIG']._serialized_end=443
  _globals['_ESTIMATERESULT']._serialized_start=445
  _globals['_ESTIMATERESULT']._serialized_end=537
  _globals['_ESTIMATERESPONSE']._serialized_start=540
  _globals['_ESTIMATERESPONSE']._serialized_end=696
  _globals['_AGEESTIMATION']._serialized_start=699
  _globals['_AGEESTIMATION']._serialized_end=858
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/voice_activity_detection/v1/voice_activity_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/voice_activity_detection/v1/voice_activity_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUphonexia/grpc/technologies/voice_activity_detection/v1/voice_activity_detection.proto\x12\x36phonexia.grpc.technologies.voice_activity_detection.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\";\n\rDetectRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\xd0\x01\n\x0e\x44\x65tectResponse\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12Q\n\x08segments\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.voice_activity_detection.v1.Segment\x12\x39\n\x16processed_audio_length\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xda\x01\n\x07Segment\x12Y\n\x04type\x18\x01 \x01(\x0e\x32K.phonexia.grpc.technologies.voice_activity_detection.v1.Segment.SegmentType\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x18\n\x0bSegmentType\x12\t\n\x05VOICE\x10\x00\x32\xb4\x01\n\x16VoiceActivityDetection\x12\x99\x01\n\x06\x44\x65tect\x12\x45.phonexia.grpc.technologies.voice_activity_detection.v1.DetectRequest\x1a\x46.phonexia.grpc.technologies.voice_activity_detection.v1.DetectResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.voice_activity_detection.v1.voice_activity_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DETECTREQUEST']._serialized_start=210
  _globals['_DETECTREQUEST']._serialized_end=269
  _globals['_DETECTRESPONSE']._serialized_start=272
  _globals['_DETECTRESPONSE']._serialized_end=480
  _globals['_SEGMENT']._serialized_start=483
  _globals['_SEGMENT']._serialized_end=701
  _globals['_SEGMENT_SEGMENTTYPE']._serialized_start=677
  _globals['_SEGMENT_SEGMENTTYPE']._serialized_end=701
  _globals['_VOICEACTIVITYDETECTION']._serialized_start=704
  _globals['_VOICEACTIVITYDETECTION']._serialized_end=884
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Replay Attack Detection gRPC API.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DetectRequest(google.protobuf.message.Message):
    """The top level message sent by the client for the <code>Detect</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data for replay attack detection.
        Technically, the audio must have at least 0.05 seconds of speech. If the audio is shorter,
        the <code>result</code> will not be present in the output. Practically, at least few seconds
        of audio should be provided for better results.
        """

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio"]) -> None: ...

Global___DetectRequest: typing_extensions.TypeAlias = DetectRequest

@typing.final
class DetectResponse(google.protobuf.message.Message):
    """The top level message returned to the client by the <code>Detect</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___DetectResult:
        """Result of replay attack detection. Will not be present if the audio is shorter than 0.05 seconds."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    def __init__(
        self,
        *,
        result: Global___DetectResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_result", b"_result", "processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_result", b"_result", "processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_result", b"_result"]) -> typing.Literal["result"] | None: ...

Global___DetectResponse: typing_extensions.TypeAlias = DetectResponse

@typing.final
class DetectResult(google.protobuf.message.Message):
    """Message representing the result of replay attack detection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_FIELD_NUMBER: builtins.int
    score: builtins.float
    """Log-likelihood ratio (LLR) of the replay attack detection. The score is a
    floating-point value. A value greater than 0 indicates the audio likely contains
    a replay attack, while a value less than 0 indicates, that the audio probably does
    not contain a replay attack.
    """
    def __init__(
        self,
        *,
        score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["score", b"score"]) -> None: ...

Global___DetectResult: typing_extensions.TypeAlias = DetectResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia 6 generation Speech To Text gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ResultType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResultTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResultType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESULT_TYPE_ONE_BEST: _ResultType.ValueType  # 0
    """Default one-best transcription result."""
    RESULT_TYPE_N_BEST: _ResultType.ValueType  # 1
    """N-best alternative transcription results."""
    RESULT_TYPE_CONFUSION_NETWORK: _ResultType.ValueType  # 2
    """Confusion network with word alternatives."""

class ResultType(_ResultType, metaclass=_ResultTypeEnumTypeWrapper):
    """Enum defining the types of results that can be returned in TranscribeResult."""

RESULT_TYPE_ONE_BEST: ResultType.ValueType  # 0
"""Default one-best transcription result."""
RESULT_TYPE_N_BEST: ResultType.ValueType  # 1
"""N-best alternative transcription results."""
RESULT_TYPE_CONFUSION_NETWORK: ResultType.ValueType  # 2
"""Confusion network with word alternatives."""
Global___ResultType: typing_extensions.TypeAlias = ResultType

class _ItemType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ItemTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ItemType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ITEM_TYPE_WORD: _ItemType.ValueType  # 0
    """<code>ITEM_TYPE_WORD</code> indicates a word.
    The <code>text</code> field of the item contains the word.
    """
    ITEM_TYPE_SILENCE: _ItemType.ValueType  # 1
    """<code>ITEM_TYPE_SILENCE</code> indicates a silence in the recording.
    The <code>text</code> field of the item contains "&lt;silence/&gt;".
    """
    ITEM_TYPE_SEGMENT_START: _ItemType.ValueType  # 2
    """<code>ITEM_TYPE_SEGMENT_START</code> indicates the start of a segment.
    A segment is a part of the recording that contains speech,
    as determined by the Voice Activity Detector (VAD).
    The <code>text</code> field of the item contains "&lt;segment&gt;".
    """
    ITEM_TYPE_SEGMENT_END: _ItemType.ValueType  # 3
    """<code>ITEM_TYPE_SEGMENT_END</code> indicates the end of a segment.
    A segment is a part of the recording that contains speech,
    as determined by the Voice Activity Detector (VAD).
    The <code>text</code> field of the item contains "&lt;/segment&gt;".
    """
    ITEM_TYPE_NULL: _ItemType.ValueType  # 4
    """<code>ITEM_TYPE_NULL</code> represents an empty alternative in a confusion network.
    The <code>text</code> field of the item contains "<null/>".
    """

class ItemType(_ItemType, metaclass=_ItemTypeEnumTypeWrapper): ...

ITEM_TYPE_WORD: ItemType.ValueType  # 0
"""<code>ITEM_TYPE_WORD</code> indicates a word.
The <code>text</code> field of the item contains the word.
"""
ITEM_TYPE_SILENCE: ItemType.ValueType  # 1
"""<code>ITEM_TYPE_SILENCE</code> indicates a silence in the recording.
The <code>text</code> field of the item contains "&lt;silence/&gt;".
"""
ITEM_TYPE_SEGMENT_START: ItemType.ValueType  # 2
"""<code>ITEM_TYPE_SEGMENT_START</code> indicates the start of a segment.
A segment is a part of the recording that contains speech,
as determined by the Voice Activity Detector (VAD).
The <code>text</code> field of the item contains "&lt;segment&gt;".
"""
ITEM_TYPE_SEGMENT_END: ItemType.ValueType  # 3
"""<code>ITEM_TYPE_SEGMENT_END</code> indicates the end of a segment.
A segment is a part of the recording that contains speech,
as determined by the Voice Activity Detector (VAD).
The <code>text</code> field of the item contains "&lt;/segment&gt;".
"""
ITEM_TYPE_NULL: ItemType.ValueType  # 4
"""<code>ITEM_TYPE_NULL</code> represents an empty alternative in a confusion network.
The <code>text</code> field of the item contains "<null/>".
"""
Global___ItemType: typing_extensions.TypeAlias = ItemType

@typing.final
class TranscribeRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Transcribe</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """The audio data to process. There is no minimum audio length limit.
        Returns EMPTY_FIELD bad parameter error if audio field is missing in the first request message.
        """

    @property
    def config(self) -> Global___TranscribeConfig:
        """Speech to text transcription configuration."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___TranscribeConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_config", b"_config", "audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_config", b"_config", "audio", b"audio", "config", b"config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_config", b"_config"]) -> typing.Literal["config"] | None: ...

Global___TranscribeRequest: typing_extensions.TypeAlias = TranscribeRequest

@typing.final
class TranscribeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFERRED_PHRASES_FIELD_NUMBER: builtins.int
    ADDITIONAL_WORDS_FIELD_NUMBER: builtins.int
    RESULT_TYPES_FIELD_NUMBER: builtins.int
    @property
    def preferred_phrases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Phrases that are preferred in transcription over other variants. Phrase consists of words spelled using graphemes
        separated by space. Graphemes that are not valid for transcription language might be used. However, the word must
        be added to <code>additional_words</code> and contains at least one pronunciation.
        Use <code>ListAllowedSymbols</code> to get allowed graphemes.
        All words from preferred phrases are automatically added to the model's dictionary and included in
        <code>TranscribeResponse.result.additional_words</code>.

        Returns UNSUPPORTED_GRAPHEME bad parameter error if a phrase contains unsupported characters.
        """

    @property
    def additional_words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___RequestedAdditionalWord]:
        """Words that are added to the default transcription dictionary.
        See RequestedAdditionalWord for field-specific validation rules.
        """

    @property
    def result_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[Global___ResultType.ValueType]:
        """Types of results to return in the response.
        If not specified, <code>RESULT_TYPE_ONE_BEST</code> will be used.
        """

    def __init__(
        self,
        *,
        preferred_phrases: collections.abc.Iterable[builtins.str] | None = ...,
        additional_words: collections.abc.Iterable[Global___RequestedAdditionalWord] | None = ...,
        result_types: collections.abc.Iterable[Global___ResultType.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["additional_words", b"additional_words", "preferred_phrases", b"preferred_phrases", "result_types", b"result_types"]) -> None: ...

Global___TranscribeConfig: typing_extensions.TypeAlias = TranscribeConfig

@typing.final
class RequestedAdditionalWord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPELLING_FIELD_NUMBER: builtins.int
    PRONUNCIATIONS_FIELD_NUMBER: builtins.int
    spelling: builtins.str
    """Word spelled using graphemes. Graphemes that are not valid for transcription
    language might be used. However, in such case, at least one pronunciation must
    be provided. Multiple words can be separated by word separator.
    Use <code>ListAllowedSymbols</code> to get allowed graphemes and word separator.

    Returns EMPTY_FIELD bad parameter error if spelling is empty.
    Returns UNSUPPORTED_GRAPHEME bad parameter error if spelling contains unsupported characters
    (only when no pronunciations are provided).
    """
    @property
    def pronunciations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Pronunciations specified using transcription language's valid phonemes.
        Individual phonemes must be separated by space. If no pronunciation is provided,
        at least one is generated by the language model. Use <code>ListAllowedSymbols</code> to get allowed phonemes.
        At least 3 phonemes are required.

        Returns EMPTY_FIELD bad parameter error if pronunciation is empty.
        Returns UNSUPPORTED_PHONEME bad parameter error if pronunciation contains unsupported phonemes.
        Returns PRONUNCIATION_TOO_SHORT bad parameter error if pronunciation contains fewer than 3 phonemes.
        """

    def __init__(
        self,
        *,
        spelling: builtins.str = ...,
        pronunciations: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pronunciations", b"pronunciations", "spelling", b"spelling"]) -> None: ...

Global___RequestedAdditionalWord: typing_extensions.TypeAlias = RequestedAdditionalWord

@typing.final
class Word(google.protobuf.message.Message):
    """Individual word with timestamps."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text of the word."""
    type: Global___ItemType.ValueType
    """Type of the word. It might be <code>ITEM_TYPE_WORD</code> or <code>ITEM_TYPE_SILENCE</code>.
    <code>ITEM_TYPE_SEGMENT_START</code>, <code>ITEM_TYPE_SEGMENT_END</code> and <code>ITEM_TYPE_NULL</code> are not allowed here.
    When type is <code>ITEM_TYPE_SILENCE</code>, text contains "&lt;silence/&gt;", otherwise text contains the word.
    Words of <code>ITEM_TYPE_SILENCE</code> are only included in OneBest if their duration is greater than 180ms.
    """
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the word."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the word."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        type: Global___ItemType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time", "text", b"text", "type", b"type"]) -> None: ...

Global___Word: typing_extensions.TypeAlias = Word

@typing.final
class OneBestSegment(google.protobuf.message.Message):
    """Segment of the one-best output."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text content of the whole segment."""
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the segment."""

    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Word]:
        """Detailed word-level segmentation of the segment."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        words: collections.abc.Iterable[Global___Word] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time", "text", b"text", "words", b"words"]) -> None: ...

Global___OneBestSegment: typing_extensions.TypeAlias = OneBestSegment

@typing.final
class OneBest(google.protobuf.message.Message):
    """The one-best output from Speech to Text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___OneBestSegment]:
        """List of transcription segments"""

    def __init__(
        self,
        *,
        segments: collections.abc.Iterable[Global___OneBestSegment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["segments", b"segments"]) -> None: ...

Global___OneBest: typing_extensions.TypeAlias = OneBest

@typing.final
class NBestSegmentAlternative(google.protobuf.message.Message):
    """Alternative of a segment."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    text: builtins.str
    """The text of the segment."""
    confidence: builtins.float
    """Confidence of the segment."""
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the segment."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        confidence: builtins.float = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "end_time", b"end_time", "start_time", b"start_time", "text", b"text"]) -> None: ...

Global___NBestSegmentAlternative: typing_extensions.TypeAlias = NBestSegmentAlternative

@typing.final
class NBestSegment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENT_ALTERNATIVES_FIELD_NUMBER: builtins.int
    @property
    def segment_alternatives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___NBestSegmentAlternative]:
        """The alternatives of the segment."""

    def __init__(
        self,
        *,
        segment_alternatives: collections.abc.Iterable[Global___NBestSegmentAlternative] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["segment_alternatives", b"segment_alternatives"]) -> None: ...

Global___NBestSegment: typing_extensions.TypeAlias = NBestSegment

@typing.final
class NBest(google.protobuf.message.Message):
    """The n-best output from Speech to Text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___NBestSegment]:
        """List of segments."""

    def __init__(
        self,
        *,
        segments: collections.abc.Iterable[Global___NBestSegment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["segments", b"segments"]) -> None: ...

Global___NBest: typing_extensions.TypeAlias = NBest

@typing.final
class ConfusionNetworkWordAlternative(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text of the word."""
    confidence: builtins.float
    """Confidence of the word."""
    type: Global___ItemType.ValueType
    """Type of the word. When type is <code>ITEM_TYPE_WORD</code> then text contains the word. In other cases text contains:
    <code>ITEM_TYPE_SILENCE</code> - "&lt;silence/&gt;"
    <code>ITEM_TYPE_SEGMENT_START</code> - "&lt;segment&gt;"
    <code>ITEM_TYPE_SEGMENT_END</code> - "&lt;/segment&gt;"
    <code>ITEM_TYPE_NULL</code> - "&lt;null/&gt;"
    """
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the segment."""

    def __init__(
        self,
        *,
        text: builtins.str = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        confidence: builtins.float = ...,
        type: Global___ItemType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "end_time", b"end_time", "start_time", b"start_time", "text", b"text", "type", b"type"]) -> None: ...

Global___ConfusionNetworkWordAlternative: typing_extensions.TypeAlias = ConfusionNetworkWordAlternative

@typing.final
class ConfusionNetworkWord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORD_ALTERNATIVES_FIELD_NUMBER: builtins.int
    @property
    def word_alternatives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ConfusionNetworkWordAlternative]:
        """Words in the time slot represent different
        variants of the word in the given time moment.
        """

    def __init__(
        self,
        *,
        word_alternatives: collections.abc.Iterable[Global___ConfusionNetworkWordAlternative] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["word_alternatives", b"word_alternatives"]) -> None: ...

Global___ConfusionNetworkWord: typing_extensions.TypeAlias = ConfusionNetworkWord

@typing.final
class ConfusionNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORDS_FIELD_NUMBER: builtins.int
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ConfusionNetworkWord]:
        """The confusion network."""

    def __init__(
        self,
        *,
        words: collections.abc.Iterable[Global___ConfusionNetworkWord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["words", b"words"]) -> None: ...

Global___ConfusionNetwork: typing_extensions.TypeAlias = ConfusionNetwork

@typing.final
class TranscribeResult(google.protobuf.message.Message):
    """Result of the Speech to Text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONE_BEST_FIELD_NUMBER: builtins.int
    N_BEST_FIELD_NUMBER: builtins.int
    CONFUSION_NETWORK_FIELD_NUMBER: builtins.int
    ADDITIONAL_WORDS_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    language: builtins.str
    """Language of the transcript."""
    @property
    def one_best(self) -> Global___OneBest:
        """The one-best output from Speech to Text."""

    @property
    def n_best(self) -> Global___NBest:
        """The n-best output from Speech to Text."""

    @property
    def confusion_network(self) -> Global___ConfusionNetwork:
        """The confusion network output from Speech to Text."""

    @property
    def additional_words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ResultingAdditionalWord]:
        """Words that were used to extend model's dictionary during transcription.
        This list is the result of their processing. If they were originally part
        of a preferred phrase, they are explicitly listed here. Furthermore, the model
        might have generated pronunciation for unknown words that were missing one.
        Lastly, if user provided a word that's already present in the model
        dictionary, all the known pronunciations were added to it.
        """

    def __init__(
        self,
        *,
        one_best: Global___OneBest | None = ...,
        n_best: Global___NBest | None = ...,
        confusion_network: Global___ConfusionNetwork | None = ...,
        additional_words: collections.abc.Iterable[Global___ResultingAdditionalWord] | None = ...,
        language: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_confusion_network", b"_confusion_network", "_n_best", b"_n_best", "_one_best", b"_one_best", "confusion_network", b"confusion_network", "n_best", b"n_best", "one_best", b"one_best"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_confusion_network", b"_confusion_network", "_n_best", b"_n_best", "_one_best", b"_one_best", "additional_words", b"additional_words", "confusion_network", b"confusion_network", "language", b"language", "n_best", b"n_best", "one_best", b"one_best"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_confusion_network", b"_confusion_network"]) -> typing.Literal["confusion_network"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_n_best", b"_n_best"]) -> typing.Literal["n_best"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_one_best", b"_one_best"]) -> typing.Literal["one_best"] | None: ...

Global___TranscribeResult: typing_extensions.TypeAlias = TranscribeResult

@typing.final
class ResultingAdditionalWord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPELLING_FIELD_NUMBER: builtins.int
    PRONUNCIATIONS_FIELD_NUMBER: builtins.int
    spelling: builtins.str
    """Word spelling as originally provided by the user."""
    @property
    def pronunciations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ResultingPronunciation]:
        """Word pronunciation after being processed by the language model."""

    def __init__(
        self,
        *,
        spelling: builtins.str = ...,
        pronunciations: collections.abc.Iterable[Global___ResultingPronunciation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pronunciations", b"pronunciations", "spelling", b"spelling"]) -> None: ...

Global___ResultingAdditionalWord: typing_extensions.TypeAlias = ResultingAdditionalWord

@typing.final
class ResultingPronunciation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRONUNCIATION_FIELD_NUMBER: builtins.int
    OUT_OF_VOCABULARY_FIELD_NUMBER: builtins.int
    pronunciation: builtins.str
    """Pronunciation specified using transcription language's valid phonemes."""
    out_of_vocabulary: builtins.bool
    """Indication of whether the pronunciation is previously unknown to the model."""
    def __init__(
        self,
        *,
        pronunciation: builtins.str = ...,
        out_of_vocabulary: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["out_of_vocabulary", b"out_of_vocabulary", "pronunciation", b"pronunciation"]) -> None: ...

Global___ResultingPronunciation: typing_extensions.TypeAlias = ResultingPronunciation

@typing.final
class TranscribeResponse(google.protobuf.message.Message):
    """TranscribeResponse is the top-level response message returned by the <code>Transcribe</code> method.
    It encapsulates segments containing the transcription results.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___TranscribeResult:
        """Transcription result for the processed audio."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total duration of the processed audio."""

    def __init__(
        self,
        *,
        result: Global___TranscribeResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___TranscribeResponse: typing_extensions.TypeAlias = TranscribeResponse

@typing.final
class ListAllowedSymbolsRequest(google.protobuf.message.Message):
    """Request message for retrieving the set of allowed graphemes and phonemes."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ListAllowedSymbolsRequest: typing_extensions.TypeAlias = ListAllowedSymbolsRequest

@typing.final
class ListAllowedSymbolsResponse(google.protobuf.message.Message):
    """Response message containing the allowed graphemes and phonemes."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRAPHEMES_FIELD_NUMBER: builtins.int
    PHONEMES_FIELD_NUMBER: builtins.int
    WORD_SEPARATOR_FIELD_NUMBER: builtins.int
    word_separator: builtins.str
    """Word separator used in <code>TranscribeConfig.additional_words.spelling</code>"""
    @property
    def graphemes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The list of allowed graphemes. Graphemes are characters used in
        <code>TranscribeConfig.preferred_phrases</code> and
        <code>RequestedAdditionalWord.spelling</code>.
        """

    @property
    def phonemes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of allowed phonemes.
        Phonemes are symbols used in the <code>RequestedAdditionalWord.pronunciations</code> field.
        Each phoneme is represented as a space-separated string and may consist of multiple characters.
        """

    def __init__(
        self,
        *,
        graphemes: collections.abc.Iterable[builtins.str] | None = ...,
        phonemes: collections.abc.Iterable[builtins.str] | None = ...,
        word_separator: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["graphemes", b"graphemes", "phonemes", b"phonemes", "word_separator", b"word_separator"]) -> None: ...

Global___ListAllowedSymbolsResponse: typing_extensions.TypeAlias = ListAllowedSymbolsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/common/core.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/common/core.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fphonexia/grpc/common/core.proto\x12\x14phonexia.grpc.common\x1a\x1egoogle/protobuf/duration.proto\"\x8d\x01\n\x05\x41udio\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x33\n\ntime_range\x18\x02 \x01(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\x12>\n\x10raw_audio_config\x18\x03 \x01(\x0b\x32$.phonexia.grpc.common.RawAudioConfig\"\xbf\x01\n\x0eRawAudioConfig\x12\x44\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32\x32.phonexia.grpc.common.RawAudioConfig.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\x12\x10\n\x08\x63hannels\x18\x03 \x01(\x05\":\n\rAudioEncoding\x12\t\n\x05PCM16\x10\x00\x12\t\n\x05PCM32\x10\x01\x12\t\n\x05MULAW\x10\x02\x12\x08\n\x04\x41LAW\x10\x03\"\x1d\n\nVoiceprint\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"C\n\x06Matrix\x12\x12\n\nrows_count\x18\x01 \x01(\x04\x12\x15\n\rcolumns_count\x18\x02 \x01(\x04\x12\x0e\n\x06values\x18\x03 \x03(\x02\"\x18\n\x06Vector\x12\x0e\n\x06values\x18\x01 \x03(\x02\"]\n\tTimeRange\x12(\n\x05start\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.common.core_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AUDIO']._serialized_start=90
  _globals['_AUDIO']._serialized_end=231
  _globals['_RAWAUDIOCONFIG']._serialized_start=234
  _globals['_RAWAUDIOCONFIG']._serialized_end=425
  _globals['_RAWAUDIOCONFIG_AUDIOENCODING']._serialized_start=367
  _globals['_RAWAUDIOCONFIG_AUDIOENCODING']._serialized_end=425
  _globals['_VOICEPRINT']._serialized_start=427
  _globals['_VOICEPRINT']._serialized_end=456
  _globals['_MATRIX']._serialized_start=458
  _globals['_MATRIX']._serialized_end=525
  _globals['_VECTOR']._serialized_start=527
  _globals['_VECTOR']._serialized_end=551
  _globals['_TIMERANGE']._serialized_start=553
  _globals['_TIMERANGE']._serialized_end=646
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Referential Deepfake Detection gRPC API.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DetectRequest(google.protobuf.message.Message):
    """The top level message sent by the client for the <code>Detect</code> method.

    This message contains both reference and questioned data for deepfake detection.
    Currently, only audio input is supported.

    The service will compare the reference data against the questioned data to determine
    if the questioned data is likely to be a deepfake of the reference speaker's voice.

    When using streaming, send the reference audio first, followed by the questioned audio.

    <b>IMPORTANT:</b> The reference data must be bona fide (genuine). If the reference
    is a deepfake, the algorithm will fail to produce valid results. Additionally, the speaker
    roles cannot be interchanged -- you must send the reference speaker in audio_reference and the
    questioned speaker in audio_questioned. Reversing these assignments may yield an incorrect score.

    The audio should contain at least 0.3125 seconds of speech. If the audio contains less speech,
    the <code>score</code> will be empty.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_REFERENCE_FIELD_NUMBER: builtins.int
    AUDIO_QUESTIONED_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio_reference(self) -> phonexia.grpc.common.core_pb2.Audio: ...
    @property
    def audio_questioned(self) -> phonexia.grpc.common.core_pb2.Audio: ...
    @property
    def config(self) -> Global___DetectConfig:
        """Optional configuration for the detection."""

    def __init__(
        self,
        *,
        audio_reference: phonexia.grpc.common.core_pb2.Audio | None = ...,
        audio_questioned: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___DetectConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio_questioned", b"audio_questioned", "audio_reference", b"audio_reference", "config", b"config", "questioned", b"questioned", "reference", b"reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio_questioned", b"audio_questioned", "audio_reference", b"audio_reference", "config", b"config", "questioned", b"questioned", "reference", b"reference"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["questioned", b"questioned"]) -> typing.Literal["audio_questioned"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["reference", b"reference"]) -> typing.Literal["audio_reference"] | None: ...

Global___DetectRequest: typing_extensions.TypeAlias = DetectRequest

@typing.final
class DetectConfig(google.protobuf.message.Message):
    """Configuration for the referential deepfake detection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum speech length to process from both reference and questioned audio.
        If set, only the first speech_length duration of speech will be processed
        from each audio. If not set, all available speech will be processed.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> None: ...

Global___DetectConfig: typing_extensions.TypeAlias = DetectConfig

@typing.final
class DetectResponse(google.protobuf.message.Message):
    """The top level message returned to the client by the <code>Detect</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___DetectResult:
        """The result of referential deepfake detection."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    def __init__(
        self,
        *,
        result: Global___DetectResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___DetectResponse: typing_extensions.TypeAlias = DetectResponse

@typing.final
class DetectResult(google.protobuf.message.Message):
    """Message representing the result of referential deepfake detection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_FIELD_NUMBER: builtins.int
    score: builtins.float
    """Score of the referential deepfake detection. A higher score indicates a higher 
    likelihood of the questioned data being a deepfake. The score is a floating-point
    value. While technically limited by floating-point representation,
    scores are typically within a certain range that varies model to model.
    Empty if not enough speech was present in the input data.
    """
    def __init__(
        self,
        *,
        score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["score", b"score"]) -> None: ...

Global___DetectResult: typing_extensions.TypeAlias = DetectResult



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/referential_deepfake_detection/v1/referential_deepfake_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/referential_deepfake_detection/v1/referential_deepfake_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\naphonexia/grpc/technologies/referential_deepfake_detection/v1/referential_deepfake_detection.proto\x12<phonexia.grpc.technologies.referential_deepfake_detection.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xf7\x01\n\rDetectRequest\x12\x36\n\x0f\x61udio_reference\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.AudioH\x00\x12\x37\n\x10\x61udio_questioned\x18\x04 \x01(\x0b\x32\x1b.phonexia.grpc.common.AudioH\x01\x12Z\n\x06\x63onfig\x18\x07 \x01(\x0b\x32J.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectConfigB\x0b\n\treferenceB\x0c\n\nquestioned\"@\n\x0c\x44\x65tectConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa7\x01\n\x0e\x44\x65tectResponse\x12Z\n\x06result\x18\x01 \x01(\x0b\x32J.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1d\n\x0c\x44\x65tectResult\x12\r\n\x05score\x18\x01 \x01(\x02\x32\xc6\x01\n\x1cReferentialDeepfakeDetection\x12\xa5\x01\n\x06\x44\x65tect\x12K.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectRequest\x1aL.phonexia.grpc.technologies.referential_deepfake_detection.v1.DetectResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.referential_deepfake_detection.v1.referential_deepfake_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DETECTREQUEST']._serialized_start=229
  _globals['_DETECTREQUEST']._serialized_end=476
  _globals['_DETECTCONFIG']._serialized_start=478
  _globals['_DETECTCONFIG']._serialized_end=542
  _globals['_DETECTRESPONSE']._serialized_start=545
  _globals['_DETECTRESPONSE']._serialized_end=712
  _globals['_DETECTRESULT']._serialized_start=714
  _globals['_DETECTRESULT']._serialized_end=743
  _globals['_REFERENTIALDEEPFAKEDETECTION']._serialized_start=746
  _globals['_REFERENTIALDEEPFAKEDETECTION']._serialized_end=944
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/denoiser/v1/denoiser.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/denoiser/v1/denoiser.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5phonexia/grpc/technologies/denoiser/v1/denoiser.proto\x12&phonexia.grpc.technologies.denoiser.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"<\n\x0e\x44\x65noiseRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\x93\x01\n\x0f\x44\x65noiseResponse\x12\x45\n\x06result\x18\x01 \x01(\x0b\x32\x35.phonexia.grpc.technologies.denoiser.v1.DenoiseResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\";\n\rDenoiseResult\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio2\x8a\x01\n\x08\x44\x65noiser\x12~\n\x07\x44\x65noise\x12\x36.phonexia.grpc.technologies.denoiser.v1.DenoiseRequest\x1a\x37.phonexia.grpc.technologies.denoiser.v1.DenoiseResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.denoiser.v1.denoiser_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DENOISEREQUEST']._serialized_start=162
  _globals['_DENOISEREQUEST']._serialized_end=222
  _globals['_DENOISERESPONSE']._serialized_start=225
  _globals['_DENOISERESPONSE']._serialized_end=372
  _globals['_DENOISERESULT']._serialized_start=374
  _globals['_DENOISERESULT']._serialized_end=433
  _globals['_DENOISER']._serialized_start=436
  _globals['_DENOISER']._serialized_end=574
# @@protoc_insertion_point(module_scope)
